import json
import sys
import time
import torch

class Saver:

    def __init__(self, model):

        assert len(sys.argv) > 1

        self.path = None
        for arg in sys.argv:
            if "--config=" in arg:
                firstsplit = arg.split("=")[1]
                index = firstsplit.rfind("/")
                self.path = firstsplit[:index] + "/model.pt"
                break

        assert self.path is not None

        self.model = model

    def save(self):
        torch.save(self.model, self.path)



import os
import sys
import json

class Args:

    def __init__(self):

        assert len(sys.argv) > 1

        path = None
        for arg in sys.argv:
            if "--config=" in arg:
                path = arg.split("=")[1]
                break

        assert path is not None

        with open(path) as json_file:
            conf = json.load(json_file)
            self.conf = conf
            for name, value in conf.items():
                setattr(self, name, value)



import csv
import sys
import time
from os import path

class Logger:

    def __init__(self):

        assert len(sys.argv) > 1

        self.path = None
        for arg in sys.argv:
            if "--config=" in arg:
                firstsplit = arg.split("=")[1]
                index = firstsplit.rfind("/")
                self.path = firstsplit[:index] + "/logs.csv" #LOOK AT NAMING, LOOK AT SLASH
                #initialize column nuames
                break

        assert self.path is not None

#output a csv instead
    def log(self, logs, framenum = time.time()):
        logs["frame"] = framenum
        if not path.exists(self.path):
            with open(self.path, mode='w') as logfile:
                fieldnames = logs.keys()
                writer = csv.DictWriter(logfile, fieldnames=fieldnames)
                writer.writeheader()
        with open(self.path, mode='a') as logfile:
            fieldnames = logs.keys()
            writer = csv.DictWriter(logfile, fieldnames=fieldnames)
            writer.writerow(logs)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="hypertuner",
    version="1.0.3",
    author="Klemen Kotar, Dian Niu",
    author_email="klemen@cs.washington.edu, dian.niu.11@gmail.com",
    description="A library for passing arguments and graphing with HyperTuner",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hypertuner/hypertuner-pythonlib",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
